@@ -38,7 +38,8 @@ from pysnmp.hlapi.asyncio import (
     usmAesCfb128Protocol,
     usmHMACMD5AuthProtocol,
 )
-from pysnmp.hlapi.asyncio.cmdgen import getCmd, setCmd
+from pysnmp.hlapi.varbinds import MibViewControllerManager
+from pysnmp.hlapi.v3arch.asyncio.cmdgen import getCmd, setCmd
 from pysnmp.smi import builder
 
 
@@ -51,8 +52,8 @@ class AtenPE(object):
 
     def __init__(
         self,
-        node: t.Union[bytes, str],
-        serv: t.Union[bytes, str, int] = "snmp",
+        node: str,
+        serv: int = 161,
         community: str = "private",
         username: str = "administrator",
         authkey: t.Optional[str] = None,
@@ -72,14 +73,17 @@ class AtenPE(object):
         else:
             self._auth_data = CommunityData(community)
         self._snmp_args: t.List[t.Any] = []
-        self._snmp_engine.getMibBuilder().addMibSources(builder.DirMibSource(Path(__file__).parent / "mibs"))
+
+        mibs_dir = Path(__file__).parent / "mibs"
+        mvc = MibViewControllerManager.get_mib_view_controller(self._snmp_engine.cache)
+        mvc.mibBuilder.add_mib_sources(builder.DirMibSource(mibs_dir))
 
     def close(self) -> None:
         self._snmp_engine.transportDispatcher.closeDispatcher()
 
-    def initialize(self) -> None:
+    async def initialize(self) -> None:
         try:
-            transport_target = UdpTransportTarget(self._addr)
+            transport_target = await UdpTransportTarget.create(self._addr)
         except PySnmpError as exc:
             raise AtenPEError(*exc.args) from exc
 
